#! /bin/sh
#------------------------------------------------------------------------------
# /tmp/install.sh - install mediatomb
#
# Creation:	2009-04-12  jk
# Last Update:  2009-06-05  jk
#
# Copyright (c) 2009 Jens Kaphingst <pekap(at)gmx(dot)de>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

package="mediatomb"
package_name="mediatomb server"

configfile=/etc/config.d/mediatomb
defaultfile=/etc/default.d/mediatomb



#------------------------------------------------------------------------------
# read eislib
#------------------------------------------------------------------------------
. /var/install/include/eislib
. /var/install/include/configlib


#------------------------------------------------------------------------------
# show infos
#------------------------------------------------------------------------------
clrhome
mecho 
mecho -info "Starting installation of mediatomb ..."


#-------------------------------------------------------------------------------
# creating symbolic links for starting/stopping mediatomb
#-------------------------------------------------------------------------------
mecho -n "creating symbolic links for mediatomb ..."

case "${EISFAIR_SYSTEM}" in
    eisfair-1)
        cd /etc/rc2.d
        rm -f S??mediatomb
        rm -f K??mediatomb
        ln -sf ../init.d/mediatomb S73mediatomb
        ln -sf ../init.d/mediatomb K27mediatomb
        cd - > /dev/null
        ;;
    *)
        stopplevels="/etc/rc0.d /etc/rc1.d /etc/rc6.d"
        startlevels="/etc/rc2.d"

        for level in $stopplevels
        do
            if [ -d "$level" ]
            then
                cd "$level"
                rm -f K??mediatomb
                ln -sf ../init.d/mediatomb K35mediatomb
                cd - > /dev/null
            fi
        done

        for level in $startlevels
        do
            if [ -d "$level" ]
            then
                cd "$level"
                rm -f K??mediatomb
                cd - > /dev/null
            fi
        done
        ;;
esac

mecho "   done"			


#------------------------------------------------------------------------------
# creating menu entry
#------------------------------------------------------------------------------
mecho
mecho -info "Adding menu entry ..."

/var/install/bin/add-menu setup.services.menu \
                          setup.services.mediatomb.menu \
                          mediatomb server
mecho "   done"

#------------------------------------------------------------------------------
# copy/update configuration file
#------------------------------------------------------------------------------
if [ -f "/etc/config.d/mediatomb" ]
then
    mecho -info "Update configuration"
    /var/install/config.d/mediatomb-update.sh
else
    mecho -info "Copying default configuration"
    cp -f ${defaultfile} ${configfile}

    mecho "   done"
fi

#------------------------------------------------------------------------------
# read configuration
#------------------------------------------------------------------------------
. /etc/config.d/mediatomb

#------------------------------------------------------------------------------
# edit configuration
#------------------------------------------------------------------------------

# convert package to PACKAGES_NAME
packages_name_upper="`echo mediatomb | tr [:lower:] [:upper:] | tr '-' '_'`"
/var/install/bin/edit -apply mediatomb "Edit mediatomb server configuration"

exit 0