#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/mediatomb-update.sh - paramater update script
#
# Creation   : 2009-04-19 jk
# Last update: 2009-06-12 jk
#
# Copyright (c) 2009 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/mediatomb-update-trace$$.log
#set -x

# set packages name
package_name=mediatomb

# include configlib for using printvar
. /var/install/include/configlib

# include eislib
. /var/install/include/eislib


# ---------------------------------------------------------------------------
# Write config and default files
# ---------------------------------------------------------------------------
createConfigFile()
{
    internal_conf_file=${1}
    (
    #--------------------------------------------------------------------------------
    printgpl -conf ${package_name} "2009-06-12" "jk" "2009 Jens Kaphingst <pekap(at)gmx(dot)de>"
    #--------------------------------------------------------------------------------

    #--------------------------------------------------------------------------------
    printgroup "General settings"
    #--------------------------------------------------------------------------------

    printvar "START_MEDIATOMB"                    "start mediatomb: yes or no"
    
    printvar "MEDIATOMB_SERVER_NAME"              "user friendly name"
    printvar "MEDIATOMB_SERVER_INTERFACE"         "interface to bind to, default: eth0"
    printvar "MEDIATOMB_SERVER_PORT"              "server port mediatomb should listen to, default: 49152, minimum port number 49152"
    printvar "MEDIATOMB_TRANSCODE_ENABLE"         "enables transcoding function: yes or no"
    printvar "MEDIATOMB_PS3_SUPPORT"              "enables support for Playstation 3: yes or no"
    printvar "MEDIATOMB_DSM320_SUPPORT"           "enables support for D-Link Mediaplayer DSM320"
    printvar "MEDIATOMB_TG100_SUPPORT"            "enables support for Telegent TG100 Mediaplayer"

    #--------------------------------------------------------------------------------
    printgroup "file name extension to mime type mapping"
    #--------------------------------------------------------------------------------

    printvar "MEDIATOMB_MIMETYPE_N"              "number of mimetypes"
    printvar ""                                  ""

    idx=1
    while [ ${idx} -le ${MEDIATOMB_MIMETYPE_N} ]
    do
        printvar "MEDIATOMB_MIMETYPE_${idx}_ACTIVE"              "is element active: yes or no"
        printvar "MEDIATOMB_MIMETYPE_${idx}_EXTENSION"           "file extension"
        printvar "MEDIATOMB_MIMETYPE_${idx}_MIMETYPE"            "mimetype"
        printvar ""                                              ""

        idx=`/usr/bin/expr ${idx} + 1`
    done
    
    #--------------------------------------------------------------------------------
    printgroup "MIME type to content type mapping"
    #--------------------------------------------------------------------------------

    printvar "MEDIATOMB_TREAT_MIMETYPE_N"              "number of mimetypes"
    printvar ""                                        ""

    idx=1
    while [ ${idx} -le ${MEDIATOMB_TREAT_MIMETYPE_N} ]
    do
        printvar "MEDIATOMB_TREAT_MIMETYPE_${idx}_ACTIVE"             "is element active: yes or no"
        printvar "MEDIATOMB_TREAT_MIMETYPE_${idx}_MIMETYPE"           "mimetype"
        printvar "MEDIATOMB_TREAT_MIMETYPE_${idx}_AS"                 "treat as content type"
        printvar ""                                                   ""

        idx=`/usr/bin/expr ${idx} + 1`
    done


    #--------------------------------------------------------------------------------
    printgroup "MIME type tp profile mapping"
    #--------------------------------------------------------------------------------

    printvar "MEDIATOMB_TRANSCODE_N"              "number of mime types to transcode"
    printvar ""                                   ""

    idx=1
    while [ ${idx} -le 6 ]
    do
        printvar "MEDIATOMB_TRANSCODE_${idx}_ACTIVE"             "is element active: yes or no"
        printvar "MEDIATOMB_TRANSCODE_${idx}_MIMETYPE"           "mimetype"
        printvar "MEDIATOMB_TRANSCODE_${idx}_PROFILE"            "using profile"
        printvar ""                                              ""

        idx=`/usr/bin/expr ${idx} + 1`
    done

    #--------------------------------------------------------------------------------
    printgroup "trancoding profiles"
    #--------------------------------------------------------------------------------

    printvar "MEDIATOMB_PROFILE_N"              "number of profiles"
    printvar ""                                 ""

    idx=1
    while [ ${idx} -le 3 ]
    do
        printvar "MEDIATOMB_PROFILE_${idx}_NAME"               "name of profile"
        printvar "MEDIATOMB_PROFILE_${idx}_ACTIVE"             "is profile active: yes or no"
        printvar "MEDIATOMB_PROFILE_${idx}_MIMETYPE"           "output mimetype"
        printvar "MEDIATOMB_PROFILE_${idx}_AGENT_COMMAND"      "name of program used for transcoding"
        printvar "MEDIATOMB_PROFILE_${idx}_AGENT_ARGUMENTS"    "argument used for transcoding"
        printvar "MEDIATOMB_PROFILE_${idx}_BUFFER_SIZE"        "buffer size: bytes"
        printvar "MEDIATOMB_PROFILE_${idx}_BUFFER_CHUNK"       "chuck size: bytes"
        printvar "MEDIATOMB_PROFILE_${idx}_BUFFER_FILLSIZE"    "fill size before server starts sending media out: bytes"
        printvar "MEDIATOMB_PROFILE_${idx}_ACCEPTURL"          "accept URL: yes or no"
        printvar "MEDIATOMB_PROFILE_${idx}_FIRSTRESSOURCE"     "set transcoded file to the first resource position: yes or no"
        printvar "MEDIATOMB_PROFILE_${idx}_HIDEORIGINAL"       "hide the original data resource: yes or no"
        printvar "MEDIATOMB_PROFILE_${idx}_ACCEPTOGGTHEORA"    "accept ogg theora codec"
        printvar "MEDIATOMB_PROFILE_${idx}_USE_FOURCCLIST"     "define a fourcc list: yes or no"
        printvar "MEDIATOMB_PROFILE_${idx}_FOURCC_MODE"        "select fourcc mode"
        printvar "MEDIATOMB_PROFILE_${idx}_FOURCC_N"           "number of fourcc codes"
        
        fcc=1
        eval fcc_cnt='$MEDIATOMB_PROFILE_'${idx}'_FOURCC_N'
        while [ ${fcc} -le ${fcc_cnt} ]
        do
            printvar "MEDIATOMB_PROFILE_${idx}_FOURCC_${fcc}_NAME"            "name of fourcc code"
            fcc=`/usr/bin/expr ${fcc} + 1`
        done
        
        printvar ""                                            ""
        
        idx=`/usr/bin/expr ${idx} + 1`
    done


    #--------------------------------------------------------------------------------
    printend
    #--------------------------------------------------------------------------------

    ) > ${internal_conf_file}
    
    # Set rights
    chmod 0600 ${internal_conf_file}
    chown root ${internal_conf_file}
}



# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------

# include default config
. /etc/default.d/${package_name}


# include mediatomb configuration, if available
if [ -f /etc/config.d/mediatomb ]
then
    . /etc/config.d/${package_name}
fi

# at this moment no update check for config variables neccessary
# --------------------------------------------------------------

# write new config file
createConfigFile /etc/config.d/${package_name}


mecho -info "Finished."

exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
