#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/mediatomb - MEDIATOMB configuration
#
# Creation   : 2009-02-11 jk
# Last update: 2009-06-12 jk
#
# Copyright (c) 2009 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/mediatomb-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Config Dateien
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# include config
. /etc/config.d/mediatomb

# set package name
package=mediatomb



#------------------------------------------------------------------------------
# get_pid
#------------------------------------------------------------------------------
function get_pid ()
{
    pidof mediatomb
}

#------------------------------------------------------------------------------
# is_running
#------------------------------------------------------------------------------
function is_running ()
{
    if [ ! -z "`get_pid`" ]; then
        # true
        return 0
    else
        # false
        return 1
    fi
}


#-------------------------------------------------------------------------------
# create mediatomb directories
#-------------------------------------------------------------------------------
create_mediatomb_directories()
{
    mecho -info "Creating directories ..."
    
    if [ ! -d "/var/mediatomb" ]
    then
        mkdir /var/mediatomb
    fi
}

#-------------------------------------------------------------------------------
# create mediatomb start file
#-------------------------------------------------------------------------------
create_mediatombstart_file ()
{
    mecho -info "creating mediatomb's start file"
    # Preset MEDIATOMB_OPTS
    MEDIATOMB_OPTS=

    # Write daemon mode
    MEDIATOMB_OPTS="${MEDIATOMB_OPTS} -d -m /var/mediatomb -f ."
    
    # Write interface if not default    
    if [ -n "${MEDIATOMB_SERVER_INTERFACE}" ]; then
        MEDIATOMB_OPTS="${MEDIATOMB_OPTS} -e ${MEDIATOMB_SERVER_INTERFACE}"
    fi

    # Write port if not default    
    if [ -n "${MEDIATOMB_SERVER_PORT}" ]; then
        MEDIATOMB_OPTS="${MEDIATOMB_OPTS} -p ${MEDIATOMB_SERVER_PORT}"
    fi

    # Write information to start-file
    STARTFILE=/usr/local/mediatomb/mediatomb-start
    cat > ${STARTFILE} << EOF
#! /bin/sh
#------------------------------------------------------------------
# ${STARTFILE} file generated by $0
#
# Do not edit this file, edit /etc/config.d/mediatomb
# Creation date: `date`
#------------------------------------------------------------------

export MEDIATOMB_DATADIR="/usr/local/mediatomb"
export MEDIATOMB_MAGIC_FILE="${MEDIATOMB_DATADIR}/magic/magic"
/usr/local/bin/mediatomb ${MEDIATOMB_OPTS}

EOF

    chmod +x ${STARTFILE}
}

#-------------------------------------------------------------------------------
# create mediatomb configuration file
#-------------------------------------------------------------------------------
create_mediatomb_configuration_file ()
{
    mecho -info "creating mediatomb's configuration file"
    
    if [ -f "/var/mediatomb/config.xml" ]
    then
        # save old uuid
        mediatomb_uuid=`grep '<udn>' /var/mediatomb/config.xml`
        if [ -z "${mediatomb_uuid}" ] 
        then
            # create uuid
            tmp=`/usr/bin/uuidgen`
            mediatomb_uuid=`echo '<udn>uuid:'$tmp'</udn>'`
        fi
    else
        # create uuid
        tmp=`/usr/bin/uuidgen`
        mediatomb_uuid=`echo '<udn>uuid:'$tmp'</udn>'`
    fi
    
    # Write information to configuration file
    CONFIGFILE="/var/mediatomb/config.xml"
    (
        echo '<?xml version="1.0" encoding="UTF-8"?>'
        echo '<config version="1" xmlns="http://mediatomb.cc/config/1" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="http://mediatomb.cc/config/1 http://mediatomb.cc/config/1.xsd">'
        echo '  <server>'
        echo '    <ui enabled="yes">'
        echo '      <accounts enabled="no" session-timeout="30">'
        echo '	<account user="mediatomb" password="mediatomb"/>'
        echo '      </accounts>'
        echo '    </ui>'
        echo '    <name>'${MEDIATOMB_SERVER_NAME}'</name>'
        echo '    '${mediatomb_uuid}
        echo '    <home>/var/mediatomb</home>'
        echo '    <webroot>/usr/local/mediatomb/web</webroot>'
        echo '    <storage>'
        echo '      <sqlite3 enabled="yes">'
        echo '	<database-file>mediatomb.db</database-file>'
        echo '      </sqlite3>'
        echo '      <mysql enabled="no">'
        echo '	<host>localhost</host>'
        echo '	<username>mediatomb</username>'
        echo '	<database>mediatomb</database>'
        echo '      </mysql>'
        echo '    </storage>'
        if [ "$MEDIATOMB_PS3_SUPPORT" == "yes" ]
        then
                echo '    <protocolInfo extend="yes"/><!-- For PS3 support change to "yes" -->'
        else
                echo '    <protocolInfo extend="no"/><!-- For PS3 support change to "yes" -->'
        fi
        
        if [ "$MEDIATOMB_DSM320_SUPPORT" == "yes" ]
        then
                echo '    <!--'
                echo '       Uncomment the lines below to get rid of jerky avi playback on the'
                echo '       DSM320 or to enable subtitles support on the DSM units'
                echo '    -->'
                echo '    <custom-http-headers>'
                echo '      <add header="X-User-Agent: redsonic"/>'
                echo '    </custom-http-headers>'
                echo
                echo '    <manufacturerURL>redsonic.com</manufacturerURL>'
                echo '    <modelNumber>105</modelNumber>'
        fi
        
        if [ "$MEDIATOMB_TG100_SUPPORT" == "yes" ]
        then
                echo '    <!-- Uncomment the line below if you have a Telegent TG100 -->'
                echo '       <upnp-string-limit>101</upnp-string-limit>'
        fi
        echo '  </server>'
        echo '  <import hidden-files="no">'
        echo '    <scripting script-charset="UTF-8">'
        echo '      <virtual-layout type="builtin"/>'
        echo '    </scripting>'
        echo '    <mappings>'
        echo '      <mimetype-upnpclass>'
        echo '	<map from="audio/*" to="object.item.audioItem.musicTrack"/>'
        echo '	<map from="video/*" to="object.item.videoItem"/>'
        echo '	<map from="image/*" to="object.item.imageItem"/>'
        echo '      </mimetype-upnpclass>'
        
        #----------------------------------------------------------------------------
        # create mimetype mapping, if MEDIATOMG_MIMETYPE_%_ACTIVE='yes':
        #----------------------------------------------------------------------------
        echo '      <extension-mimetype ignore-unknown="no">'

        idx='1'
        while [ $idx -le $MEDIATOMB_MIMETYPE_N ]
        do
                eval active='$MEDIATOMB_MIMETYPE_'$idx'_ACTIVE'
                eval extension='$MEDIATOMB_MIMETYPE_'$idx'_EXTENSION'
                eval mimetype='$MEDIATOMB_MIMETYPE_'$idx'_MIMETYPE'
        
                if [ "$active" == "yes" ]
                then
                        echo '	<map from="'$extension'" to="'$mimetype'"/>'
                fi

                idx=`/usr/bin/expr $idx + 1`
        done
        echo '      </extension-mimetype>'

        #----------------------------------------------------------------------------
        # treat mimetype as content type, if MEDIATOMG_MIMETYPE_%_ACTIVE='yes':
        #----------------------------------------------------------------------------
        echo '      <mimetype-contenttype>'

        idx='1'
        while [ $idx -le $MEDIATOMB_TREAT_MIMETYPE_N ]
        do
                eval active='$MEDIATOMB_TREAT_MIMETYPE_'$idx'_ACTIVE'
                eval mimetype='$MEDIATOMB_TREAT_MIMETYPE_'$idx'_MIMETYPE'
                eval contenttype='$MEDIATOMB_TREAT_MIMETYPE_'$idx'_AS'

                if [ "$active" == "yes" ]
                then
                        echo '	<treat mimetype="'$mimetype'" as="'$contenttype'"/>'
                fi

                idx=`/usr/bin/expr $idx + 1`
        done
        echo '      </mimetype-contenttype>'

        echo '    </mappings>'
        echo '  </import>'
        echo '  <transcoding enabled="'$MEDIATOMB_TRANSCODE_ENABLE'">'

        #----------------------------------------------------------------------------
        # transcoding mimetype to profile mapping
        #----------------------------------------------------------------------------
        echo '    <mimetype-profile-mappings>'

        idx='1'
        while [ $idx -le $MEDIATOMB_TRANSCODE_N ]
        do
                eval active='$MEDIATOMB_TRANSCODE_'$idx'_ACTIVE'
                eval mimetype='$MEDIATOMB_TRANSCODE_'$idx'_MIMETYPE'
                eval profile='$MEDIATOMB_TRANSCODE_'$idx'_PROFILE'

                if [ "$active" == "yes" ]
                then
                        echo '      <transcode mimetype="'$mimetype'" using="'$profile'"/>'
                fi

                idx=`/usr/bin/expr $idx + 1`
        done
        echo '    </mimetype-profile-mappings>'

        #----------------------------------------------------------------------------
        # creating profiles
        #----------------------------------------------------------------------------
        echo '    <profiles>'
        idx='1'
        while [ $idx -le $MEDIATOMB_PROFILE_N ]
        do
                eval profilename='$MEDIATOMB_PROFILE_'$idx'_NAME'
                eval active='$MEDIATOMB_PROFILE_'$idx'_ACTIVE'
                eval mimetype='$MEDIATOMB_PROFILE_'$idx'_MIMETYPE'
                eval agentcommand='$MEDIATOMB_PROFILE_'$idx'_AGENT_COMMAND'
                eval agentargs='$MEDIATOMB_PROFILE_'$idx'_AGENT_ARGUMENTS'
                eval buffersize='$MEDIATOMB_PROFILE_'$idx'_BUFFER_SIZE'
                eval chunksize='$MEDIATOMB_PROFILE_'$idx'_BUFFER_CHUNK'
                eval fillsize='$MEDIATOMB_PROFILE_'$idx'_BUFFER_FILLSIZE'
                eval accepturl='$MEDIATOMB_PROFILE_'$idx'_ACCEPTURL'
                eval firstres='$MEDIATOMB_PROFILE_'$idx'_FIRSTRESSOURCE'
                eval hideorig='$MEDIATOMB_PROFILE_'$idx'_HIDEORIGINAL'
                eval acceptoggtheora='$MEDIATOMB_PROFILE_'$idx'_ACCEPTOGGTHEORA'
                eval usefourcc='$MEDIATOMB_PROFILE_'$idx'_USE_FOURCCLIST'

                echo '      <profile name="'$profilename'" enabled="'$active'" type="external">'
                echo '	<mimetype>'$mimetype'</mimetype>'
                echo '	<agent command="'$agentcommand'" arguments="'$agentargs'"/>'
                echo '	<buffer size="'$buffersize'" chunk-size="'$chunksize'" fill-size="'fillsize'"/>'
                echo '	<accept-url>'$accepturl'</accept-url>'
                echo '	<first-resource>'$firstres'</first-resource>'
                echo '	<hide-original-resource>'$hideorig'</hide-original-resource>'
                echo '	<accept-ogg-theora>'$acceptoggtheora'</accept-ogg-theora>'

                if [ "$active" == "yes" ]
                then
                        if [ "$usefourcc" == "yes" ]
                        then
                                eval fourccmode='$MEDIATOMB_PROFILE_'$idx'_FOURCC_MODE'
                                eval fourcc_n='$MEDIATOMB_PROFILE_'$idx'_FOURCC_N'

                                echo '	<avi-fourcc-list mode="'$fourccmode'">'

                                idx1='1'
                                while [ $idx1 -le $fourcc_n ]
                                do
                                        eval fourcc_code='$MEDIATOMB_PROFILE_'$idx'_FOURCC_'$idx1'_NAME'
                                        echo '	  <fourcc>'$fourcc_code'</fourcc>'

                                        idx1=`/usr/bin/expr $idx1 + 1`
                                done

                                echo '	</avi-fourcc-list>'
                        fi
                fi

                echo '      </profile>'

                idx=`/usr/bin/expr $idx + 1`
        done

        echo '    </profiles>'
        echo '  </transcoding>'
        echo '</config>'
        echo
    ) > ${CONFIGFILE}
    chmod +x ${CONFIGFILE}
}


#-------------------------------------------------------------------------------
# check if mediatomb server port is free to use
#-------------------------------------------------------------------------------
check_mediatomb_port ()
{
    mecho -info "Checking mediatomb's server port"
    PORT_USED=`lsof -i -n -P | grep ":${MEDIATOMB_SERVER_PORT} "`
    if [ -n "${PORT_USED}" ]; then
        PORT_USER=`echo "${PORT_USED}" | grep "mediatomb"`
        if [ -z "${PORT_USER}" ]; then
            mecho -error "Port ${MEDIATOMB_SERVER_PORT} is used by another program!"
            mecho -info "You have to edit configuration file again"
            anykey
            exec /var/install/bin/mediatomb-edit
        fi
    fi
}


# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
create_mediatomb_directories
check_mediatomb_port
create_mediatombstart_file
create_mediatomb_configuration_file 

# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------
exit 0